@@ -2,8 +2,8 @@
 
 #include <QtTestWidgets>
 
-#include "kactioncollection.h"
 #include "kactioncategory.h"
+#include "kactioncollection.h"
 #include <KSelectAction>
 #include <KStandardAction>
 
@@ -151,7 +151,10 @@ void tst_KActionCategory::tstActionCreation()
     // There should be 6 actions inside the collection and category
     QCOMPARE(category.actions().count(), 6);
     QCOMPARE(collection.actions().count(), 6);
+    delete action1;
+    delete action2;
 }
 
 QTEST_MAIN(tst_KActionCategory)
 
+#include "moc_kactioncategorytest.cpp"
