@@ -8,7 +8,9 @@
 #include "testguiclient.h"
 #include "testxmlguiwindow.h"
 
+#ifdef QT_DBUS_LIB
 #include <QDBusConnection>
+#endif
 #include <QDir>
 #include <QFile>
 #include <QFileInfo>
@@ -237,6 +239,7 @@ void tst_KToolBar::testIconSizeNoXmlGui()
         const bool mainToolBarWasUsingDefaultSize = iconSize == KIconLoader::global()->currentSize(KIconLoader::MainToolbar);
         const bool otherToolBarWasUsingDefaultSize = iconSize == KIconLoader::global()->currentSize(KIconLoader::Toolbar);
 
+#ifndef Q_OS_WIN // the change notification uses DBus
         // Now emulate a change of the kde-global setting (#168480#c12)
         changeGlobalIconSizeSetting(32, 33);
 
@@ -254,6 +257,7 @@ void tst_KToolBar::testIconSizeNoXmlGui()
             QCOMPARE(otherToolBar->iconSize().width(), iconSize);
         }
         QCOMPARE(cleanToolBar->iconSize().width(), 33);
+#endif
     }
 }
 
@@ -319,6 +323,7 @@ void tst_KToolBar::testIconSizeXmlGui()
             QVERIFY(group.group("Toolbar mainToolBar").hasKey("IconSize"));
         }
 
+#ifndef Q_OS_WIN // the change notification uses DBus
         // Now emulate a change of the kde-global setting (#168480#c12)
         changeGlobalIconSizeSetting(25, 16);
 
@@ -326,6 +331,7 @@ void tst_KToolBar::testIconSizeXmlGui()
         QCOMPARE(otherToolBar->iconSize().width(), expectedSizeOtherToolbar);
         QCOMPARE(cleanToolBar->iconSize().width(), expectedSizeCleanToolbar);
         QCOMPARE(bigToolBar->iconSize().width(), expectedSizeBigToolbar);
+#endif
 
         // The big unchanged toolbar should be, well, unchanged; AppXml has priority over KDE_Default.
         QCOMPARE(bigUnchangedToolBar->iconSize().width(), 32);
@@ -343,7 +349,7 @@ void tst_KToolBar::changeGlobalIconSizeSetting(int mainToolbarIconSize, int icon
     globals.writeEntry("Size", iconSize);
     KSharedConfig::openConfig()->sync();
 
-    QSignalSpy spy(KIconLoader::global(), SIGNAL(iconChanged(int)));
+    QSignalSpy spy(KIconLoader::global(), &KIconLoader::iconChanged);
     KIconLoader::global()->emitChange(KIconLoader::Desktop);
     spy.wait(200);
 }
@@ -356,7 +362,7 @@ void tst_KToolBar::deleteGlobalIconSizeSetting()
     globals.deleteEntry("Size");
     KSharedConfig::openConfig()->sync();
 
-    QSignalSpy spy(KIconLoader::global(), SIGNAL(iconChanged(int)));
+    QSignalSpy spy(KIconLoader::global(), &KIconLoader::iconChanged);
     KIconLoader::global()->emitChange(KIconLoader::Desktop);
     spy.wait(200);
 }
@@ -416,6 +422,7 @@ void tst_KToolBar::testToolButtonStyleNoXmlGui()
         QCOMPARE((int)mainToolBar->toolButtonStyle(), (int)toolButtonStyle);
         QCOMPARE((int)otherToolBar->toolButtonStyle(), (int)toolButtonStyle);
 
+#ifndef Q_OS_WIN // the change notification uses DBus
         // Now change KDE-global setting
         changeGlobalToolButtonStyleSetting(QStringLiteral("IconOnly"), QStringLiteral("TextOnly"));
 
@@ -430,6 +437,7 @@ void tst_KToolBar::testToolButtonStyleNoXmlGui()
         } else {
             QCOMPARE((int)otherToolBar->toolButtonStyle(), (int)toolButtonStyle);
         }
+#endif
     }
 }
 
@@ -478,12 +486,14 @@ void tst_KToolBar::testToolButtonStyleXmlGui()
         // Save settings
         kmw.saveMainWindowSettings(group);
 
+#ifndef Q_OS_WIN // the change notification uses DBus
         // Now change KDE-global setting
         changeGlobalToolButtonStyleSetting(QStringLiteral("IconOnly"), QStringLiteral("TextOnly"));
 
         QCOMPARE((int)mainToolBar->toolButtonStyle(), (int)expectedStyleMainToolbar);
         QCOMPARE((int)otherToolBar->toolButtonStyle(), (int)expectedStyleOtherToolbar);
         QCOMPARE((int)cleanToolBar->toolButtonStyle(), (int)expectedStyleCleanToolbar);
+#endif
     }
 }
 
@@ -495,16 +505,18 @@ void tst_KToolBar::changeGlobalToolButtonStyleSetting(const QString &mainToolBar
     group.sync();
 
     // Same dbus connect as the one in KToolBar. We want our spy to be notified of receiving it.
+#ifdef QT_DBUS_LIB
     QDBusConnection::sessionBus().connect(QString(),
                                           QStringLiteral("/KToolBar"),
                                           QStringLiteral("org.kde.KToolBar"),
                                           QStringLiteral("styleChanged"),
                                           this,
                                           SIGNAL(signalAppearanceChanged()));
-    QSignalSpy spy(this, SIGNAL(signalAppearanceChanged()));
+    QSignalSpy spy(this, &tst_KToolBar::signalAppearanceChanged);
 
     KToolBar::emitToolbarStyleChanged();
     spy.wait(2000);
+#endif
 }
 
 void tst_KToolBar::deleteGlobalToolButtonStyleSetting()
