@@ -1,39 +1,25 @@
 /*
-   Copyright (c) 2000 Bernd Johannes Wuebben <wuebben@math.cornell.edu>
-   Copyright (c) 2000 Stephan Kulow <coolo@kde.org>
+    SPDX-FileCopyrightText: 2000 Bernd Johannes Wuebben <wuebben@math.cornell.edu>
+    SPDX-FileCopyrightText: 2000 Stephan Kulow <coolo@kde.org>
 
-   This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "main.h"
 #include <qplatformdefs.h>
 
-#include <QTextStream>
 #include <QApplication>
 #include <QHostInfo>
+#include <QTextStream>
 
-#include <kemailsettings.h>
-#include <klocalizedstring.h>
+#include <KEMailSettings>
+#include <KLocalizedString>
 
-#include <kconfig.h>
-#include <qcommandlineparser.h>
 #include <qcommandlineoption.h>
+#include <qcommandlineparser.h>
 
-#include "smtp.h"
 #include "../systeminformation_p.h"
-
+#include "smtp.h"
 
 void BugMailer::slotError(int errornum)
 {
@@ -72,23 +58,26 @@ void BugMailer::slotSend()
 
 int main(int argc, char **argv)
 {
-
     QCoreApplication a(argc, argv);
     a.setApplicationName(QStringLiteral("ksendbugmail"));
     a.setApplicationVersion(QStringLiteral("1.0"));
 
     KLocalizedString::setApplicationDomain("kxmlgui5");
 
-    //d.addAuthor(ki18n("Stephan Kulow"), ki18n("Author"), "coolo@kde.org");
+    // d.addAuthor(ki18n("Stephan Kulow"), ki18n("Author"), "coolo@kde.org");
 
-    QString subject, recipient;
+    QString subject;
+    QString recipient;
     {
         QCommandLineParser parser;
         parser.addVersionOption();
         parser.setApplicationDescription(i18n("Sends a bug report by email."));
         parser.addHelpOption();
         parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("subject"), i18n("The subject line of the email."), QStringLiteral("argument")));
-        parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("recipient"), i18n("The email address to send the bug report to."), QStringLiteral("argument"), QStringLiteral("submit@bugs.kde.org")));
+        parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("recipient"),
+                                            i18n("The email address to send the bug report to."),
+                                            QStringLiteral("argument"),
+                                            QStringLiteral("submit@bugs.kde.org")));
         parser.process(a);
         recipient = parser.value(QStringLiteral("recipient"));
         subject = parser.value(QStringLiteral("subject"));
@@ -110,8 +99,12 @@ int main(int argc, char **argv)
         }
     }
     QTextStream input(stdin, QIODevice::ReadOnly);
+    // The default in Qt6 is UTF-8
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     input.setCodec("UTF-8");
-    QString text, line;
+#endif
+    QString text;
+    QString line;
     while (!input.atEnd()) {
         line = input.readLine();
         text += line + QLatin1String("\r\n");
@@ -131,7 +124,7 @@ int main(int argc, char **argv)
     }
     // qCDebug(DEBUG_KXMLGUI) << "fromaddr \"" << fromaddr << "\"";
 
-    QString  server = emailConfig.getSetting(KEMailSettings::OutServer);
+    QString server = emailConfig.getSetting(KEMailSettings::OutServer);
     if (server.isEmpty()) {
         server = QStringLiteral("bugs.kde.org");
     }
@@ -156,3 +149,4 @@ int main(int argc, char **argv)
     return r;
 }
 
+#include "moc_main.cpp"
