@@ -24,10 +24,12 @@
 #include <QDomDocument>
 #include <QFile>
 #include <QStandardPaths>
-#include <QTextCodec>
 #include <QTextStream>
 #include <QVariant>
 #include <QWidget>
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#include <QTextCodec>
+#endif
 
 #include <KConfigGroup>
 #include <KSharedConfig>
@@ -161,7 +163,10 @@ bool KXMLGUIFactory::saveConfigFile(const QDomDocument &doc, const QString &file
 
     // write out our document
     QTextStream ts(&file);
+    // The default in Qt6 is UTF-8
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     ts.setCodec(QTextCodec::codecForName("UTF-8"));
+#endif
     ts << doc;
 
     file.close();
@@ -172,6 +177,8 @@ KXMLGUIFactory::KXMLGUIFactory(KXMLGUIBuilder *builder, QObject *parent)
     : QObject(parent)
     , d(new KXMLGUIFactoryPrivate)
 {
+    Q_INIT_RESOURCE(kxmlgui);
+
     d->builder = builder;
     d->guiClient = nullptr;
     if (d->builder) {
@@ -395,7 +402,7 @@ void KXMLGUIFactory::changeShortcutScheme(const QString &scheme)
 
 void KXMLGUIFactory::forgetClient(KXMLGUIClient *client)
 {
-    d->m_clients.removeAll(client);
+    d->m_clients.erase(std::remove(d->m_clients.begin(), d->m_clients.end(), client), d->m_clients.end());
 }
 
 void KXMLGUIFactory::removeClient(KXMLGUIClient *client)
@@ -412,7 +419,7 @@ void KXMLGUIFactory::removeClient(KXMLGUIClient *client)
     }
 
     // remove this client from our client list
-    d->m_clients.removeAll(client);
+    forgetClient(client);
 
     // remove child clients first (create a copy of the list just in case the
     // original list is modified directly or indirectly in removeClient())
@@ -768,3 +775,5 @@ QDomElement KXMLGUIFactory::findActionByName(QDomElement &elem, const QString &s
     }
     return QDomElement();
 }
+
+#include "moc_kxmlguifactory.cpp"
